@@ -74,20 +74,14 @@ int main
 {
 	GOptionContext *context;
 	GOptionGroup *baconoptiongroup;
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 	GtkWidget *win, *bvw;
 	GtkSettings *gtk_settings;
-	GtkBox *box;
-	GtkToolItem *item;
-	GtkWidget *image;
 
 #ifdef GDK_WINDOWING_X11
 	XInitThreads ();
 #endif
 
-	if (gtk_clutter_init (NULL, NULL) != CLUTTER_INIT_SUCCESS)
-		g_assert_not_reached ();
-
 	context = g_option_context_new ("- Play audio and video inside a web browser");
 	baconoptiongroup = bacon_video_widget_get_option_group();
 	g_option_context_add_main_entries (context, option_entries, GETTEXT_PACKAGE);
@@ -97,7 +91,6 @@ int main
 
 	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
 		g_print ("Failed to parse options: %s\n", error->message);
-		g_error_free (error);
 		return 1;
 	}
 	if (filenames != NULL &&
@@ -116,46 +109,18 @@ int main
 	g_signal_connect (G_OBJECT (win), "destroy",
 			G_CALLBACK (gtk_main_quit), NULL);
 
-	bvw = bacon_video_widget_new (NULL);
-	bacon_video_widget_set_logo (BACON_VIDEO_WIDGET (bvw), "org.gnome.Totem");
+	bvw = bacon_video_widget_new ();
+	if (!bacon_video_widget_check_init (BACON_VIDEO_WIDGET (bvw), &error)) {
+		g_warning ("Failed to instantiate video widget: %s", error->message);
+		return 1;
+	}
 
 	g_signal_connect (G_OBJECT (bvw), "eos", G_CALLBACK (on_eos_event), NULL);
 	g_signal_connect (G_OBJECT (bvw), "got-metadata", G_CALLBACK (on_got_metadata), NULL);
 	g_signal_connect (G_OBJECT (bvw), "got-redirect", G_CALLBACK (on_redirect), NULL);
 	g_signal_connect (G_OBJECT (bvw), "error", G_CALLBACK (error_cb), NULL);
 
-	box = g_object_get_data (bacon_video_widget_get_controls_object (BACON_VIDEO_WIDGET (bvw)), "controls_box");
-
-	/* Previous */
-	item = gtk_tool_button_new (NULL, NULL);
-	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item), "media-skip-backward-symbolic");
-	gtk_box_pack_start (box, GTK_WIDGET (item), FALSE, FALSE, 0);
-
-	/* Play/Pause */
-	item = gtk_tool_button_new (NULL, NULL);
-	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item), "media-playback-start-symbolic");
-	gtk_box_pack_start (box, GTK_WIDGET (item), FALSE, FALSE, 0);
-
-	/* Next */
-	item = gtk_tool_button_new (NULL, NULL);
-	gtk_tool_button_set_icon_name (GTK_TOOL_BUTTON (item), "media-skip-forward-symbolic");
-	gtk_box_pack_start (box, GTK_WIDGET (item), FALSE, FALSE, 0);
-
-	/* Separator */
-	item = gtk_separator_tool_item_new ();
-	gtk_box_pack_start (box, GTK_WIDGET (item), FALSE, FALSE, 0);
-
-	/* Go button */
-	item = g_object_get_data (bacon_video_widget_get_controls_object (BACON_VIDEO_WIDGET (bvw)), "go_button");
-	image = gtk_image_new_from_icon_name ("view-more-symbolic", GTK_ICON_SIZE_SMALL_TOOLBAR);
-	gtk_button_set_image (GTK_BUTTON (item), image);
-
-	gtk_widget_show_all (GTK_WIDGET (box));
-
-	gtk_container_add (GTK_CONTAINER (win),bvw);
-
-	gtk_widget_realize (GTK_WIDGET (win));
-	gtk_widget_realize (bvw);
+	gtk_container_add (GTK_CONTAINER (win), bvw);
 
 	gtk_widget_show (win);
 	gtk_widget_show (bvw);
@@ -164,8 +129,6 @@ int main
 		test_bvw_set_mrl (bvw, filenames[0]);
 		argument = g_strdup (filenames[0]);
 		bacon_video_widget_play (BACON_VIDEO_WIDGET (bvw), NULL);
-	} else {
-		bacon_video_widget_set_logo_mode (BACON_VIDEO_WIDGET (bvw), TRUE);
 	}
 
 	gtk_main ();
