@@ -69,6 +69,7 @@ media_is_local (GrlMedia *media)
 
 	id = grl_media_get_source (media);
 	if (g_strcmp0 (id, "grl-tracker-source") == 0 ||
+	    g_strcmp0 (id, "grl-tracker3-source") == 0 ||
 	    g_strcmp0 (id, "grl-filesystem") == 0 ||
 	    g_strcmp0 (id, "grl-bookmarks") == 0)
 		return TRUE;
@@ -192,6 +193,7 @@ thumbnail_media_async_thread (GTask    *task,
 	GdkPixbuf *pixbuf, *tmp_pixbuf;
 	const char *uri;
 	GDateTime *mtime;
+	gint64 unix_date;
 
 	if (g_task_return_error_if_cancelled (task)) {
 		g_object_unref (task);
@@ -210,9 +212,10 @@ thumbnail_media_async_thread (GTask    *task,
 		key_id = grl_registry_lookup_metadata_key (registry, "bookmark-date");
 		mtime = grl_data_get_boxed (GRL_DATA (media), key_id);
 	}
+	unix_date = mtime ? g_date_time_to_unix (mtime) : g_get_real_time () / 1000000;
 
-	if (!uri || !mtime) {
-		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_FAILED, "URI or mtime missing");
+	if (!uri) {
+		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_FAILED, "URI missing");
 		g_object_unref (task);
 		return;
 	}
@@ -225,7 +228,7 @@ thumbnail_media_async_thread (GTask    *task,
 		return;
 	}
 
-	gnome_desktop_thumbnail_factory_save_thumbnail (factory, tmp_pixbuf, uri, g_date_time_to_unix (mtime));
+	gnome_desktop_thumbnail_factory_save_thumbnail (factory, tmp_pixbuf, uri, unix_date);
 
 	/* Save the thumbnail URL for the bookmarks source */
 	save_bookmark_thumbnail (media, uri);
