@@ -41,18 +41,16 @@
 
 #define TOTEM_TYPE_IM_STATUS_PLUGIN		(totem_im_status_plugin_get_type ())
 #define TOTEM_IM_STATUS_PLUGIN(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), TOTEM_TYPE_IM_STATUS_PLUGIN, TotemImStatusPlugin))
-#define TOTEM_IM_STATUS_PLUGIN_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), TOTEM_TYPE_IM_STATUS_PLUGIN, TotemImStatusPluginClass))
-#define TOTEM_IS_IM_STATUS_PLUGIN(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), TOTEM_TYPE_IM_STATUS_PLUGIN))
-#define TOTEM_IS_IM_STATUS_PLUGIN_CLASS(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), TOTEM_TYPE_IM_STATUS_PLUGIN))
-#define TOTEM_IM_STATUS_PLUGIN_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), TOTEM_TYPE_IM_STATUS_PLUGIN, TotemImStatusPluginClass))
 
 typedef struct {
+	PeasExtensionBase parent;
+
 	guint		handler_id_fullscreen;
 	guint		handler_id_playing;
 	GCancellable   *cancellable;
 	gboolean	idle; /* Whether we're idle */
 	GDBusProxy     *proxy;
-} TotemImStatusPluginPrivate;
+} TotemImStatusPlugin;
 
 enum {
 	STATUS_AVAILABLE = 0,
@@ -70,11 +68,11 @@ totem_im_status_set_idleness (TotemImStatusPlugin *pi,
 	GVariant *variant;
 	GError *error = NULL;
 
-	if (pi->priv->idle == idle)
+	if (pi->idle == idle)
 		return;
 
-	pi->priv->idle = idle;
-	variant = g_dbus_proxy_call_sync (pi->priv->proxy,
+	pi->idle = idle;
+	variant = g_dbus_proxy_call_sync (pi->proxy,
 					  "SetStatus",
 					  g_variant_new ("(u)", idle ? STATUS_BUSY : STATUS_AVAILABLE),
 					  G_DBUS_CALL_FLAGS_NONE,
@@ -94,7 +92,7 @@ totem_im_status_update_from_state (TotemObject         *totem,
 				   TotemImStatusPlugin *pi)
 {
 	/* Session Proxy not ready yet */
-	if (pi->priv->proxy == NULL)
+	if (pi->proxy == NULL)
 		return;
 
 	if (totem_object_is_playing (totem) != FALSE
@@ -120,17 +118,19 @@ got_proxy_cb (GObject             *source_object,
 {
 	GError *error = NULL;
 	TotemObject *totem;
+	GDBusProxy *proxy;
 
-	pi->priv->proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
-
-	g_object_unref (pi->priv->cancellable);
-	pi->priv->cancellable = NULL;
-
-	if (pi->priv->proxy == NULL) {
-		g_warning ("Failed to contact session manager: %s", error->message);
+	proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
+	if (!proxy) {
+		g_debug ("Could not connect to SessionManager: %s", error->message);
 		g_error_free (error);
 		return;
 	}
+
+	pi->proxy = proxy;
+	g_object_unref (pi->cancellable);
+	pi->cancellable = NULL;
+
 	g_object_get (pi, "object", &totem, NULL);
 	totem_im_status_update_from_state (totem, pi);
 	g_object_unref (totem);
@@ -142,7 +142,7 @@ impl_activate (PeasActivatable *plugin)
 	TotemImStatusPlugin *pi = TOTEM_IM_STATUS_PLUGIN (plugin);
 	TotemObject *totem;
 
-	pi->priv->cancellable = g_cancellable_new ();
+	pi->cancellable = g_cancellable_new ();
 	g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION,
 				  G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
 				  G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
@@ -150,17 +150,17 @@ impl_activate (PeasActivatable *plugin)
 				  "org.gnome.SessionManager",
 				  "/org/gnome/SessionManager/Presence",
 				  "org.gnome.SessionManager.Presence",
-				  pi->priv->cancellable,
+				  pi->cancellable,
 				  (GAsyncReadyCallback) got_proxy_cb,
 				  pi);
 
 	g_object_get (plugin, "object", &totem, NULL);
 
-	pi->priv->handler_id_fullscreen = g_signal_connect (G_OBJECT (totem),
+	pi->handler_id_fullscreen = g_signal_connect (G_OBJECT (totem),
 				"notify::fullscreen",
 				G_CALLBACK (property_notify_cb),
 				pi);
-	pi->priv->handler_id_playing = g_signal_connect (G_OBJECT (totem),
+	pi->handler_id_playing = g_signal_connect (G_OBJECT (totem),
 				"notify::playing",
 				G_CALLBACK (property_notify_cb),
 				pi);
@@ -175,28 +175,28 @@ impl_deactivate (PeasActivatable *plugin)
 	TotemObject *totem;
 
 	/* In flight? */
-	if (pi->priv->cancellable != NULL) {
-		g_cancellable_cancel (pi->priv->cancellable);
-		g_object_unref (pi->priv->cancellable);
-		pi->priv->cancellable = NULL;
+	if (pi->cancellable != NULL) {
+		g_cancellable_cancel (pi->cancellable);
+		g_object_unref (pi->cancellable);
+		pi->cancellable = NULL;
 	}
 
-	if (pi->priv->proxy != NULL) {
-		g_object_unref (pi->priv->proxy);
-		pi->priv->proxy = NULL;
+	if (pi->proxy != NULL) {
+		g_object_unref (pi->proxy);
+		pi->proxy = NULL;
 	}
 
 	g_object_get (plugin, "object", &totem, NULL);
 
-	if (pi->priv->handler_id_fullscreen != 0) {
+	if (pi->handler_id_fullscreen != 0) {
 		g_signal_handler_disconnect (G_OBJECT (totem),
-					     pi->priv->handler_id_fullscreen);
-		pi->priv->handler_id_fullscreen = 0;
+					     pi->handler_id_fullscreen);
+		pi->handler_id_fullscreen = 0;
 	}
-	if (pi->priv->handler_id_playing != 0) {
+	if (pi->handler_id_playing != 0) {
 		g_signal_handler_disconnect (G_OBJECT (totem),
-					     pi->priv->handler_id_playing);
-		pi->priv->handler_id_playing = 0;
+					     pi->handler_id_playing);
+		pi->handler_id_playing = 0;
 	}
 
 	g_object_unref (totem);
