@@ -38,22 +38,20 @@
 
 #define TOTEM_TYPE_ROTATION_PLUGIN		(totem_rotation_plugin_get_type ())
 #define TOTEM_ROTATION_PLUGIN(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), TOTEM_TYPE_ROTATION_PLUGIN, TotemRotationPlugin))
-#define TOTEM_ROTATION_PLUGIN_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), TOTEM_TYPE_ROTATION_PLUGIN, TotemRotationPluginClass))
-#define TOTEM_IS_ROTATION_PLUGIN(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), TOTEM_TYPE_ROTATION_PLUGIN))
-#define TOTEM_IS_ROTATION_PLUGIN_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), TOTEM_TYPE_ROTATION_PLUGIN))
-#define TOTEM_ROTATION_PLUGIN_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), TOTEM_TYPE_ROTATION_PLUGIN, TotemRotationPluginClass))
 
 #define GIO_ROTATION_FILE_ATTRIBUTE "metadata::totem::rotation"
 #define STATE_COUNT 4
 
 typedef struct {
+	PeasExtensionBase parent;
+
 	TotemObject *totem;
 	GtkWidget   *bvw;
 
 	GCancellable *cancellable;
 	GSimpleAction *rotate_left_action;
 	GSimpleAction *rotate_right_action;
-} TotemRotationPluginPrivate;
+} TotemRotationPlugin;
 
 TOTEM_PLUGIN_REGISTER(TOTEM_TYPE_ROTATION_PLUGIN, TotemRotationPlugin, totem_rotation_plugin)
 
@@ -76,27 +74,26 @@ store_state_cb (GObject      *source_object,
 static void
 store_state (TotemRotationPlugin *pi)
 {
-	TotemRotationPluginPrivate *priv = pi->priv;
 	BvwRotation rotation;
 	char *rotation_s;
 	GFileInfo *info;
 	char *mrl;
 	GFile *file;
 
-	rotation = bacon_video_widget_get_rotation (BACON_VIDEO_WIDGET (priv->bvw));
+	rotation = bacon_video_widget_get_rotation (BACON_VIDEO_WIDGET (pi->bvw));
 	rotation_s = g_strdup_printf ("%u", rotation);
 	info = g_file_info_new ();
 	g_file_info_set_attribute_string (info, GIO_ROTATION_FILE_ATTRIBUTE, rotation_s);
 	g_free (rotation_s);
 
-	mrl = totem_object_get_current_mrl (priv->totem);
+	mrl = totem_object_get_current_mrl (pi->totem);
 	file = g_file_new_for_uri (mrl);
 	g_free (mrl);
 	g_file_set_attributes_async (file,
 				     info,
 				     G_FILE_QUERY_INFO_NONE,
 				     G_PRIORITY_DEFAULT,
-				     priv->cancellable,
+				     pi->cancellable,
 				     store_state_cb,
 				     pi);
 	g_object_unref (file);
@@ -126,11 +123,11 @@ restore_state_cb (GObject      *source_object,
 	pi = user_data;
 
 	rotation_s = g_file_info_get_attribute_string (info, GIO_ROTATION_FILE_ATTRIBUTE);
-	if (!rotation_s)
+	if (!rotation_s || *rotation_s == '\0')
 		goto out;
 
 	rotation = atoi (rotation_s);
-	bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (pi->priv->bvw), rotation);
+	bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (pi->bvw), rotation);
 
 out:
 	g_object_unref (info);
@@ -139,11 +136,10 @@ out:
 static void
 restore_state (TotemRotationPlugin *pi)
 {
-	TotemRotationPluginPrivate *priv = pi->priv;
 	char *mrl;
 	GFile *file;
 
-	mrl = totem_object_get_current_mrl (priv->totem);
+	mrl = totem_object_get_current_mrl (pi->totem);
 	file = g_file_new_for_uri (mrl);
 	g_free (mrl);
 
@@ -151,7 +147,7 @@ restore_state (TotemRotationPlugin *pi)
 				 GIO_ROTATION_FILE_ATTRIBUTE,
 				 G_FILE_QUERY_INFO_NONE,
 				 G_PRIORITY_DEFAULT,
-				 priv->cancellable,
+				 pi->cancellable,
 				 restore_state_cb,
 				 pi);
 	g_object_unref (file);
@@ -161,16 +157,12 @@ static void
 update_state (TotemRotationPlugin *pi,
 	      const char          *mrl)
 {
-	TotemRotationPluginPrivate *priv = pi->priv;
-
 	if (mrl == NULL) {
-		bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (priv->bvw),
-					 BVW_ROTATION_R_ZERO);
-		g_simple_action_set_enabled (priv->rotate_left_action, FALSE);
-		g_simple_action_set_enabled (priv->rotate_right_action, FALSE);
+		g_simple_action_set_enabled (pi->rotate_left_action, FALSE);
+		g_simple_action_set_enabled (pi->rotate_right_action, FALSE);
 	} else {
-		g_simple_action_set_enabled (priv->rotate_left_action, TRUE);
-		g_simple_action_set_enabled (priv->rotate_right_action, TRUE);
+		g_simple_action_set_enabled (pi->rotate_left_action, TRUE);
+		g_simple_action_set_enabled (pi->rotate_right_action, TRUE);
 		restore_state (pi);
 	}
 }
@@ -181,11 +173,10 @@ cb_rotate_left (GSimpleAction *simple,
 		gpointer       user_data)
 {
 	TotemRotationPlugin *pi = user_data;
-	TotemRotationPluginPrivate *priv = pi->priv;
         int state;
 
-        state = (bacon_video_widget_get_rotation (BACON_VIDEO_WIDGET (priv->bvw)) - 1) % STATE_COUNT;
-        bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (priv->bvw), state);
+        state = (bacon_video_widget_get_rotation (BACON_VIDEO_WIDGET (pi->bvw)) - 1) % STATE_COUNT;
+        bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (pi->bvw), state);
         store_state (pi);
 }
 
@@ -195,11 +186,10 @@ cb_rotate_right (GSimpleAction *simple,
 		 gpointer       user_data)
 {
 	TotemRotationPlugin *pi = user_data;
-	TotemRotationPluginPrivate *priv = pi->priv;
         int state;
 
-        state = (bacon_video_widget_get_rotation (BACON_VIDEO_WIDGET (priv->bvw)) + 1) % STATE_COUNT;
-        bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (priv->bvw), state);
+        state = (bacon_video_widget_get_rotation (BACON_VIDEO_WIDGET (pi->bvw)) + 1) % STATE_COUNT;
+        bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (pi->bvw), state);
         store_state (pi);
 }
 
@@ -222,44 +212,43 @@ static void
 impl_activate (PeasActivatable *plugin)
 {
 	TotemRotationPlugin *pi = TOTEM_ROTATION_PLUGIN (plugin);
-	TotemRotationPluginPrivate *priv = pi->priv;
 	GMenu *menu;
 	GMenuItem *item;
 	char *mrl;
 	const char * const rotate_cw[]= { "<Primary>r", NULL };
 	const char * const rotate_ccw[]= { "<Primary><Shift>r", NULL };
 
-	priv->totem = g_object_get_data (G_OBJECT (plugin), "object");
-	priv->bvw = totem_object_get_video_widget (priv->totem);
-	priv->cancellable = g_cancellable_new ();
+	pi->totem = g_object_get_data (G_OBJECT (plugin), "object");
+	pi->bvw = totem_object_get_video_widget (pi->totem);
+	pi->cancellable = g_cancellable_new ();
 
-	g_signal_connect (priv->totem,
+	g_signal_connect (pi->totem,
 			  "file-opened",
 			  G_CALLBACK (totem_rotation_file_opened),
 			  plugin);
-	g_signal_connect (priv->totem,
+	g_signal_connect (pi->totem,
 			  "file-closed",
 			  G_CALLBACK (totem_rotation_file_closed),
 			  plugin);
 
 	/* add UI */
-	menu = totem_object_get_menu_section (priv->totem, "rotation-placeholder");
+	menu = totem_object_get_menu_section (pi->totem, "rotation-placeholder");
 
-	priv->rotate_left_action = g_simple_action_new ("rotate-left", NULL);
-	g_signal_connect (G_OBJECT (priv->rotate_left_action), "activate",
+	pi->rotate_left_action = g_simple_action_new ("rotate-left", NULL);
+	g_signal_connect (G_OBJECT (pi->rotate_left_action), "activate",
 			  G_CALLBACK (cb_rotate_left), pi);
-	g_action_map_add_action (G_ACTION_MAP (priv->totem),
-				 G_ACTION (priv->rotate_left_action));
-	gtk_application_set_accels_for_action (GTK_APPLICATION (priv->totem),
+	g_action_map_add_action (G_ACTION_MAP (pi->totem),
+				 G_ACTION (pi->rotate_left_action));
+	gtk_application_set_accels_for_action (GTK_APPLICATION (pi->totem),
 					       "app.rotate-left",
 					       rotate_ccw);
 
-	priv->rotate_right_action = g_simple_action_new ("rotate-right", NULL);
-	g_signal_connect (G_OBJECT (priv->rotate_right_action), "activate",
+	pi->rotate_right_action = g_simple_action_new ("rotate-right", NULL);
+	g_signal_connect (G_OBJECT (pi->rotate_right_action), "activate",
 			  G_CALLBACK (cb_rotate_right), pi);
-	g_action_map_add_action (G_ACTION_MAP (priv->totem),
-				 G_ACTION (priv->rotate_right_action));
-	gtk_application_set_accels_for_action (GTK_APPLICATION (priv->totem),
+	g_action_map_add_action (G_ACTION_MAP (pi->totem),
+				 G_ACTION (pi->rotate_right_action));
+	gtk_application_set_accels_for_action (GTK_APPLICATION (pi->totem),
 					       "app.rotate-right",
 					       rotate_cw);
 
@@ -271,7 +260,7 @@ impl_activate (PeasActivatable *plugin)
 	g_menu_item_set_attribute (item, "accel", "s", "<Primary><Shift>R");
 	g_menu_append_item (G_MENU (menu), item);
 
-	mrl = totem_object_get_current_mrl (priv->totem);
+	mrl = totem_object_get_current_mrl (pi->totem);
 	update_state (pi, mrl);
 	g_free (mrl);
 }
@@ -280,31 +269,27 @@ static void
 impl_deactivate (PeasActivatable *plugin)
 {
 	TotemRotationPlugin *pi = TOTEM_ROTATION_PLUGIN (plugin);
-	TotemRotationPluginPrivate *priv = pi->priv;
 	const char * const accels[] = { NULL };
 
-	if (priv->cancellable != NULL) {
-		g_cancellable_cancel (priv->cancellable);
-		g_clear_object (&priv->cancellable);
+	if (pi->cancellable != NULL) {
+		g_cancellable_cancel (pi->cancellable);
+		g_clear_object (&pi->cancellable);
 	}
 
-	g_signal_handlers_disconnect_by_func (priv->totem, totem_rotation_file_opened, plugin);
-	g_signal_handlers_disconnect_by_func (priv->totem, totem_rotation_file_closed, plugin);
+	g_signal_handlers_disconnect_by_func (pi->totem, totem_rotation_file_opened, plugin);
+	g_signal_handlers_disconnect_by_func (pi->totem, totem_rotation_file_closed, plugin);
 
-	gtk_application_set_accels_for_action (GTK_APPLICATION (priv->totem),
+	gtk_application_set_accels_for_action (GTK_APPLICATION (pi->totem),
 					       "app.rotate-right",
 					       accels);
-	gtk_application_set_accels_for_action (GTK_APPLICATION (priv->totem),
+	gtk_application_set_accels_for_action (GTK_APPLICATION (pi->totem),
 					       "app.rotate-left",
 					       accels);
 
-	totem_object_empty_menu_section (priv->totem, "rotation-placeholder");
-	g_action_map_remove_action (G_ACTION_MAP (priv->totem), "rotate-left");
-	g_action_map_remove_action (G_ACTION_MAP (priv->totem), "rotate-right");
+	totem_object_empty_menu_section (pi->totem, "rotation-placeholder");
+	g_action_map_remove_action (G_ACTION_MAP (pi->totem), "rotate-left");
+	g_action_map_remove_action (G_ACTION_MAP (pi->totem), "rotate-right");
 
-	bacon_video_widget_set_rotation (BACON_VIDEO_WIDGET (priv->bvw),
-					 BVW_ROTATION_R_ZERO);
-
-	priv->totem = NULL;
-	priv->bvw = NULL;
+	pi->totem = NULL;
+	pi->bvw = NULL;
 }
