@@ -31,12 +31,18 @@ G_BEGIN_DECLS
 void totem_app_menu_setup (Totem *totem);
 void totem_app_actions_setup (Totem *totem);
 
-void totem_sublang_update (Totem *totem);
-void totem_sublang_exit (Totem *totem);
+void totem_subtitles_menu_update (Totem *totem);
+void totem_languages_menu_update (Totem *totem);
 
 /* For test use only */
+typedef struct {
+	char *label;
+	int id;
+} MenuItem;
+
 GList *bvw_lang_info_to_menu_labels (GList        *langs,
 				     BvwTrackType  track_type);
+void free_menu_item (MenuItem *item);
 
 G_END_DECLS
 
