@@ -46,7 +46,7 @@
 		widget = GTK_WIDGET (gtk_builder_get_object (xml, name));	\
 		gtk_widget_set_sensitive (widget, state);			\
 	}
-#define totem_controls_set_sensitivity(name, state) gtk_widget_set_sensitive (g_object_get_data (totem->controls, name), state)
+#define totem_controls_set_sensitivity(name, state) gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (totem->xml, name)), state)
 
 #define totem_object_set_sensitivity2(name, state)					\
 	{										\
@@ -75,13 +75,13 @@ struct _TotemObject {
 	GtkWidget *win;
 	GtkWidget *stack;
 	BaconVideoWidget *bvw;
+	GtkWidget *bvw_grid;
 	GtkWidget *prefs;
-	GtkBuilder *prefs_xml;
 	GtkWindow *shortcuts_win;
+	GtkWidget *spinner;
 
 	GtkWidget *grilo;
 
-	GObject *controls;
 	GtkWidget *play_button;
 	BaconTimeLabel *time_label;
 	BaconTimeLabel *time_rem_label;
@@ -89,6 +89,7 @@ struct _TotemObject {
 
 	GtkWidget *fullscreen_header;
 	GtkWidget *fullscreen_gear_button;
+	GtkWidget *fullscreen_subtitles_button;
 
 	/* Plugins */
 	GtkWidget *plugins;
@@ -108,11 +109,12 @@ struct _TotemObject {
 
 	/* Subtitles/Languages menus */
 	gboolean updating_menu;
-	GList *subtitles_list;
-	GList *languages_list;
 
 	/* controls management */
 	ControlsVisibility controls_visibility;
+	gboolean reveal_controls;
+	guint transition_timeout_id;
+	GHashTable *busy_popup_ht; /* key=reason string, value=gboolean */
 
 	/* Stream info */
 	gint64 stream_length;
@@ -139,6 +141,7 @@ struct _TotemObject {
 	GtkWidget *gear_button;
 	GtkWidget *add_button;
 	GtkWidget *main_menu_button;
+	GtkWidget *subtitles_button;
 
 	char *player_title;
 
